@@ -15,9 +15,6 @@ fn main() {
 	]);
 
 	let learnt = learn(&map, None);
-	println!("!{:?}", learnt.0);
-	
-	map.encourage(1, 1);
 
 	// * This output should be "Hola mundo"
 	let es: String = run("Hello world", &learnt, None, None, None, Some(0));
@@ -26,7 +23,6 @@ fn main() {
 	let en: String = run("Hola mundo", &learnt, None, None, None, Some(0));
 
 
-
 	test_result!("ES", es, "Hola mundo.");
 	test_result!("EN", en, "Hello world.");
 }
