@@ -5,7 +5,7 @@ use colored::Colorize;
 macro_rules! test_result_ {
 	($name: expr, $x: ident, $supposed: expr) => {
 		if $x == $supposed {
-			println!("{} {} ; Result was:", $name.bold(), "OK".black().italic().on_bright_green());
+			println!("{} {} ; Result was: {}", $name.bold(), "OK".black().italic().on_bright_green(), $supposed.italic().on_bright_green());
 		} else {
 			println!(
 				"{} {}{} \"{}\"{}{}",
